@@ -18,9 +18,9 @@ LANG=C rpm --checksig kernel-4.4.110-2vl6.src.rpm | grep -F ': (sha1) dsa sha1 m
 rpm -ivh kernel-4.4.110-2vl6.src.rpm || die "Can't install source package."
 
 cd ~/rpm/SOURCES/ || die "Can't chdir to ~/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.6-20191111.tar.gz ]
+if [ ! -r ccs-patch-1.8.6-20191225.tar.gz ]
 then
-    wget -O ccs-patch-1.8.6-20191111.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.6-20191111.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.6-20191225.tar.gz 'https://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.6-20191225.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -33,7 +33,7 @@ patch << "EOF" || die "Can't patch spec file."
  %define kversion 4.%{sublevel}
  %define rpmversion 4.%{sublevel}.%{patchlevel}
 -%define release 2%{?_dist_release}
-+%define release 2%{?_dist_release}_tomoyo_1.8.6
++%define release 2%{?_dist_release}_tomoyo_1.8.6p1
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.6-20191111.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.6-20191225.tar.gz
 +patch -sp1 < patches/ccs-patch-4.4-vine-linux-6.diff
 +
  cp %{SOURCE10} Documentation/
